@@ -38,11 +38,8 @@ impl<'a> Trailer<'a> {
     /// )
     /// ```
     #[must_use]
-    pub fn new(key: String, value: String) -> Trailer<'a> {
-        Self {
-            key: Cow::from(key),
-            value: Cow::from(value),
-        }
+    pub const fn new(key: Cow<'a, str>, value: Cow<'a, str>) -> Trailer<'a> {
+        Self { key, value }
     }
 
     /// Get the key of the [`Trailer`]
@@ -96,13 +93,13 @@ impl<'a> Hash for Trailer<'a> {
 }
 
 impl<'a> From<Trailer<'a>> for String {
-    fn from(trailer: Trailer) -> Self {
+    fn from(trailer: Trailer<'_>) -> Self {
         format!("{}: {}", trailer.key, trailer.value)
     }
 }
 
 impl<'a> From<Trailer<'a>> for Fragment<'a> {
-    fn from(trailer: Trailer) -> Self {
+    fn from(trailer: Trailer<'_>) -> Self {
         let trailer: String = trailer.into();
         Body::from(trailer).into()
     }
@@ -123,12 +120,14 @@ impl<'a> TryFrom<Body<'a>> for Trailer<'a> {
             .next()
             .ok_or_else(|| Error::new_not_a_trailer(&body))?;
 
-        Ok(Trailer::new(key, value))
+        Ok(Trailer::new(key.into(), value.into()))
     }
 }
 
+/// Errors in parsing potential trailers
 #[derive(Error, Debug, Diagnostic)]
 pub enum Error {
+    /// When the given fragment is not a trailer
     #[error("not a trailer")]
     #[diagnostic(url(docsrs), code(mit_commit::trailer::error::not_atrailer))]
     NotATrailer(
@@ -138,7 +137,7 @@ pub enum Error {
 }
 
 impl Error {
-    fn new_not_a_trailer(body: &Body) -> Self {
+    fn new_not_a_trailer(body: &Body<'_>) -> Self {
         let text: String = body.clone().into();
         Self::NotATrailer(text.clone(), (0, text.len()))
     }
